eprllib.RewardFunctions.energy_rewards — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.RewardFunctions.energy_rewards

## Energy rewards

The rewards based on energy variables/meters.

### Herarchical versions

Note that herarchical versions are the same function but insteade of using only the inmediate value of the variable/meter, the reward is calculated using a List of the last timesteps and integrating or averaging them.

Classes

`energy_with_meters`(reward_fn_config) |
`herarchical_energy_with_meters`(reward_fn_config) |